from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x08\x00\x55\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x9b\x08\x00\x00\x00\x00\x00\x18\x46\x3b\xa5\x8a\x43\x6e\xfa\x46\x27\xa0\x6f\xe2\x1d\xc9\x65\x79\x00\x00\x00\x00\x00\x00\x00\x00\x18\x6d\xe4\x80\x09\x92\xd2\x88\x9d\x1b\xfa\x4b\x8f\x11\x2f\x6c\x19\xf3\x86\x52\x92\xf6\x2e\x44\x0e\xef\xcb\xbd\x56\xbd\x25\x22\x75\x63\xfa\x4e\xc4\x6d\x91\x0c\x63\x1a\xa2\x6f\xb3\x2b\x22\xfa\x48\x2a\xcd\x4e\x24\x26\xbe\x06\xe3\x0a\xa1\x9e\x7b\x83\x8b\x41\x87\x24\x5d\x61\x80\x7e\xf2\xbf\xf9\xa4\xaf\xbf\xb5\x07\x50\xa4\x71\x34\xf5\x5f\xe5\x17\x7d\x33\x2a\x9f\x68\x7a\xfb\x01\x84\xa8\xdc\x12\x49\xbd\x26\x58\x5b\x93\x1d\xc7\xc0\x58\xfa\x24\xc8\x63\x2a\x36\xae\xb0\xb2\x6f\xcf\xef\xcb\xee\x2a\xaf\x94\x6a\x11\x86\x77\x4a\xa7\x19\xb1\x64\xf9\x2d\xf6\x8d\xe1\x65\x8c\xa7\x41\x0c\x94\x36\x51\xe0\xdc\x07\x32\xb4\x9d\x7e\xbc\x24\x13\x0a\x11\x86\x4e\x7b\x57\x43\x3f\x6e\x53\xc5\x5e\x44\x27\xc0\x52\x4a\xec\xf4\x2c\x90\x86\x07\x71\x92\x61\x78\x94\x48\x8e\xb3\x5b\x50\xa0\x7f\x30\xd9\x46\x35\x0a\x34\x4e\xf1\x82\x7b\xa0\x03\x8c\x6d\x71\x7a\x54\xa6\xec\x85\x09\x42\x0c\x70\x02\xd0\x80\xe6\x0d\x9a\x5e\x81\x8b\x70\xff\x87\x3c\x0f\xe0\xd1\xc9\x25\x36\xc0\x2b\xba\x04\x54\xa2\xaa\xa1\x27\x38\x73\x5a\x78\xf6\x4a\x36\x65\xab\x87\x86\x9e\xbd\x51\x2d\x3d\x54\x99\x55\xab\x6e\xfc\x02\x84\x07\x97\x82\x38\x87\x4a\xea\x81\xaf\xdb\x44\xda\xed\x31\xc5\xd3\x4a\x1f\xce\x94\x69\x19\x8f\x4a\x72\x75\x27\x07\x35\x62\x73\xc5\xca\x26\xdc\x77\xbd\xfd\x11\xc0\xe4\xf6\x1e\xfe\xc0\xb0\x7d\x0a\xd1\xa0\x68\xa5\x00\xb5\x3f\x0c\x10\x57\x28\x5e\xa7\x9d\x6b\xf2\x2f\x1c\x5b\x6f\x53\xdf\x7d\x35\x16\xb4\xb0\x65\x11\xbd\x25\xb7\x37\x07\xdb\x9c\xe7\x6e\x20\x14\xcb\x63\x63\xf1\xaa\x93\xb5\x69\xcc\xe5\x22\xc8\x22\x52\x2b\x2e\xc7\x6b\x15\x5e\x74\xc7\xe7\x4b\x17\xdd\xea\x40\x0d\xc4\x95\x40\xd2\xf6\x80\xb8\xbc\x1c\x5d\xfa\xa8\x6d\x02\x16\x8d\xbe\x24\x2c\x48\xf3\x4e\x72\x11\x33\xaa\x1b\xfc\xde\x93\x8e\x8a\xde\x6c\x71\xe7\x79\x47\x9b\xec\x29\xfa\x68\x6a\x69\xd1\x25\xc3\x70\x91\x0e\x42\x18\xc9\x82\x52\xda\xa8\xcd\x58\xaf\xb8\x76\xd5\x96\x51\xf5\xc9\xed\xd4\x79\x80\xe3\xc6\x1d\xa2\xd5\xfd\x1a\xb4\x63\x92\x73\xd8\xff\xc9\x24\xd5\xd0\xb0\x30\x9f\xe5\x9f\x55\xa1\x94\x95\x1e\x5c\x29\x5e\x32\x2c\x80\x9e\xef\x2d\xda\x12\x51\xa3\x96\x59\x54\x95\x36\xf3\xc2\xdf\x8f\x4b\xd0\xf0\x48\x4f\x52\x1e\x34\x62\x2b\xc3\x48\xf0\x39\x52\xdc\xdc\x9c\x55\x73\x46\x46\x98\x55\xca\x16\xb0\x78\x77\xe8\xc9\x39\x97\xd0\xed\xec\x79\x9c\xb8\x0a\x2a\xd6\x14\x7c\x8c\x0d\x90\x3d\x05\x99\xd0\xcc\x9d\x4f\x18\x79\x49\xa9\x52\xa0\xdd\x73\xf4\x8f\xe0\x20\x5b\x92\x6d\x93\x9d\x00\x07\x45\x96\x5a\x4a\x56\x01\xd0\xe9\x7b\xe3\x7e\xf6\x0d\x9e\xa2\xa4\x3e\x00\x0e\x5d\xc2\x7e\x30\xc7\x20\x29\x46\xcc\xed\xde\x35\x83\x2e\x80\xac\xb3\xc5\x99\x44\x2a\x0a\xc8\xae\xad\x1c\x8b\x4e\x2e\x62\x37\x9e\xbf\xf5\x5f\xe6\xd8\x2a\x08\x2b\xb8\xa6\x72\x9d\xb2\x9e\xe3\x3e\x4c\x09\xdc\xf4\x55\xaf\x9e\x17\x29\xd8\x06\x34\xa2\xf2\xae\xe6\x44\xb3\xab\x42\x7a\x70\xe9\x4a\x73\x6a\x44\xf7\x68\x7e\xc5\x3f\x63\x15\x70\xd3\x16\xf3\xbb\x86\x44\xdd\xd4\x7e\xa5\x5a\x38\x4a\xac\x6f\x63\xf8\x55\xb1\xa1\xce\xf5\x8a\x82\xfc\x65\x9c\x33\x9c\x48\x6c\x78\x0f\xec\x9e\x05\x99\xa7\x08\x98\xc1\x6c\xd5\xb5\x57\xbe\x2b\x43\xc8\xf0\x39\xde\x4b\x8a\xa6\x23\x61\xdb\x3f\x53\x02\x61\x1b\x48\xc7\x06\xe2\x93\x64\x31\x8a\x06\x27\x3d\x43\xa3\x40\xf1\x58\x69\x77\x2a\x04\xaa\x81\xb5\x9f\xb0\xd9\x8f\x1f\x50\xed\x68\x91\xc5\xbc\x62\x76\x01\x0d\x09\x12\xe9\x98\xf5\xdb\x9c\xa0\x7a\x8e\x04\xdd\xf4\x4d\x5c\xee\x21\x4f\x48\x26\xbd\x56\x98\xd5\xc0\xd7\x95\x66\x4b\x66\xab\x8a\xbb\xd4\x52\xde\xba\xc7\xd5\x98\x35\xf7\xc5\xbb\xcf\x2d\xf2\x7c\xc7\x9e\xb8\x61\xc9\x84\x73\x59\xb0\x00\xa8\x7b\x31\x8c\xf9\x44\xad\xf8\xd0\x23\x16\x34\xc1\xdd\xad\x0d\xe6\x26\x47\x19\x2a\xf6\x76\x35\x63\x6a\x0c\x36\xf7\x3a\xc5\x34\x9e\x3e\xe0\x17\xd5\xb8\xfb\xad\x87\x4e\x6f\x91\xa6\xc7\x00\x1b\x2f\x32\x8c\x19\xd7\x8c\xfb\xb3\x70\xde\x0e\x9e\x87\xcf\xdd\x0c\x35\x57\x66\x31\xc3\x9c\x07\x29\x12\xb8\x5a\x72\xc5\xc4\x6f\xd8\x7a\xbb\xae\x8d\xa1\x20\xb2\xd5\xd6\xd6\x1d\xaf\xbe\x27\x85\x84\x26\x35\x67\xf0\xbb\xd8\xb0\x86\x7b\x1f\x7e\xff\xf6\x33\x64\xe1\xcf\x17\x8b\x63\x57\xe8\xc9\xa0\x12\xcd\x27\x1c\x91\x23\xef\x31\x32\xed\xf3\x40\x34\x2d\x20\x94\x9d\x85\xf9\x87\xa9\x76\xb4\x7d\x2f\x51\xc9\x81\x78\x0a\x84\x5e\xba\xb8\x32\x35\x96\x38\xa4\x6c\x91\x09\x80\xd1\xbf\xff\x5b\x72\xcd\x01\x91\xfa\xee\x40\x06\xcc\xc7\x02\x2d\x9f\x78\x51\x1b\xb1\x01\xd6\x25\xe4\x43\x32\xdd\x6b\x42\xe9\x9b\xe7\x6c\xf7\x16\x93\x56\xc5\xa2\x7b\x2d\x15\xca\xb9\x03\xe9\xb5\x14\xe0\x1b\xf5\x91\xcf\x70\xf3\x75\x41\x33\x91\x52\xa2\x8e\x0f\x87\x40\xcc\xb7\xcc\xc1\x3c\x28\x81\xca\x3b\x20\x87\x06\x16\x5b\x0c\xb6\x65\x67\xb1\xba\x7c\x86\x5e\x23\xd0\x45\x24\xf6\x63\x3c\xed\xed\xc7\xe4\x02\x25\x95\x6d\xd4\x5e\xa9\xee\x85\x5d\x32\x9e\xa7\xb4\x3c\x54\x14\xb8\x1c\xeb\xf9\x57\x6f\x4d\x2c\xf1\xde\xce\xc3\x98\xfc\x7d\x85\xf8\xad\x48\x1f\x52\x87\x99\x2a\x60\x1c\xa4\x27\x83\x81\xe3\xce\xef\x89\xb2\x39\xdf\xdf\x19\x92\xb2\xa1\x4c\x7f\x6b\xfb\xe9\x3b\xb7\xa0\x34\x26\xb2\x5f\xab\xf7\x8e\x8a\x00\xaa\x2c\xce\xe0\x88\xaf\xfb\x79\x8e\x65\x6d\x68\x03\xb7\x0a\x03\xd9\x54\xa6\x50\xa0\xb9\x0f\xe1\x74\x6a\x7d\xf8\x84\xc4\xcb\xac\xfc\xe8\xfb\x82\x82\x31\x5b\x09\x85\x51\x26\xb9\x04\x89\x0d\xe7\x3c\x9c\x0f\xd7\xae\x41\xfa\x81\x3f\xfe\x8b\x0b\x0c\x2d\x7f\x70\x82\x54\x68\x79\x8b\xdf\x14\x9a\x89\x62\xbd\x66\x40\x61\xb2\x4b\x52\x9b\x2f\xed\x55\x31\x10\xbf\xb0\xf7\x10\x52\x15\x5e\x2a\xab\x66\x3a\x22\x00\x7f\x4c\xdd\x2e\xc3\x43\xc1\x5c\xc5\x19\x78\x87\xf2\x61\xf6\xb4\xf8\x57\x35\x75\x3c\x8c\x11\x42\x9c\x05\xed\x66\xa1\x11\x06\x99\xa7\x27\x55\xff\x06\x1c\xcd\xf8\xdd\x6f\x10\xc1\x44\xf2\x8d\x75\x1a\x94\x1e\x12\x59\x87\xb9\xe9\x8f\x99\xe8\x79\x47\x4a\xf1\x50\x76\xfa\x9b\x76\xeb\x1c\xed\x7f\xc3\x7a\x63\xee\x75\x52\x71\x89\xae\xd4\xc5\x46\xb3\x4f\x33\x7d\x8c\xd9\x41\x07\xf3\xca\x30\xb1\x93\x8e\x09\x13\xaa\xa3\x28\xfc\x24\x01\xc6\x77\xe0\x94\x07\x38\xc4\x44\xa3\xec\x22\x7b\x59\x1f\xca\x2b\xad\xa7\xa2\x35\xc3\x88\x16\x8d\xae\xb1\x9d\x08\x8a\x98\x99\x88\x0d\x2c\x50\x96\xf6\x09\xd1\xb3\x7a\x08\x49\xa2\x6a\xd1\xed\x18\x51\x5a\xe6\x00\x0f\xcf\xd6\xa8\xd0\x5c\x67\x27\x66\xab\x8f\xf1\xb2\x4f\xc4\x97\x6a\x43\x9d\x37\xbf\x47\xe1\xf8\xbb\x19\x91\xc3\xc2\x9b\x7f\x23\x4b\x54\xbb\xc6\xe7\xab\xa5\x07\x2f\x31\x01\xc7\xcf\x69\xc4\xc9\x16\xbb\x8b\xfe\xed\x17\x7f\x29\x93\xe1\x97\xbf\xb2\x6b\xf6\xf6\xb9\x34\x16\xa3\x01\xc1\x19\x47\x40\xc3\xfe\x5e\x71\xcf\xbc\xe0\x11\x7e\x59\x09\x81\x75\x1e\x99\xc8\x91\xe0\x39\x52\x57\x01\xb8\xc7\x89\xd9\x8a\x9a\xf9\xbf\x43\xed\x14\xed\xfe\x86\x5c\x1d\x1e\xc5\x5b\x65\xe9\x17\x2a\xc1\x18\x9c\x7b\x1c\x90\xd6\x31\x0a\x48\x84\x48\x8d\xb3\xf4\xb4\x53\x07\x1e\x46\x4b\xba\x62\x4c\x7c\x96\x7a\x1b\x4b\xaf\x5f\x8d\x68\xa9\x02\xc5\x8b\x8c\x85\x9c\x0a\xed\xbc\x7f\xde\x91\x2d\x6e\x85\x39\x5d\x52\x7d\xbc\x79\x21\xd5\xb1\xd7\xdb\x4e\xe2\x61\xb6\x2d\x68\xa9\xbf\xa5\x80\x9a\x85\x6c\x4a\x6d\x79\x14\xf6\x2f\x00\x61\x65\x5e\xdf\xb9\x8f\x75\x17\xdb\x8a\xcb\x04\xac\x26\x1d\xb9\xc7\x99\xec\x7f\x96\x6e\x69\x83\x30\x18\x57\x0e\x19\x7d\x71\x8e\x9d\x14\x9b\xb3\xf2\x1d\x70\xdf\x03\xf1\xc3\x86\xe4\x42\xca\xf8\x07\x65\x8d\x8c\x89\x3e\xe1\xae\x98\x85\xc9\xec\x50\x15\x49\xd1\xcc\x64\x14\x6d\x7d\x32\x03\x6c\x34\x41\xb3\xee\x30\xdb\x96\xdd\xb5\x28\x2e\x24\xdb\x00\x50\x7a\xc4\x20\x3d\x21\x42\xa7\xc0\x00\x8c\x15\x2b\x73\x87\xc8\x9a\x47\x58\x46\x88\xb7\x54\xa9\x98\xd4\xb6\xe3\x5d\xd1\x1d\x9a\xdb\x4f\x27\x1b\xda\x16\xc6\x7a\x2f\xf4\x71\x69\xa6\x27\xa7\x3f\xce\x53\x99\xc6\xe5\x4c\x61\x20\x0f\x9a\xf7\x3e\x1a\x54\xd5\xdc\xd9\xc9\x8b\xb1\x02\x28\x9f\x38\xc6\x47\x58\xee\x8f\x15\x14\xd2\x25\xd8\xcc\xcb\x09\x8c\x58\x5f\x8e\x6c\x32\x56\x14\x57\xa0\xa3\x6b\x27\x43\x7b\x01\x80\x4b\x49\x01\xb0\x58\x58\xd7\xec\x67\x62\x48\xc4\xa5\x66\xa3\x10\x5c\xdc\x79\xf7\xeb\x2b\x36\x4f\xa1\x7a\x22\xed\xf1\x76\x8a\xcf\xcf\x6b\xd0\x0b\xfc\x42\xe4\xb5\x53\x9e\xa1\xf3\x48\xb9\xa0\x45\x5f\x7d\x0c\x57\xab\xfa\xd2\xc4\xec\x38\xe4\x0e\xa9\xd0\x2e\x44\x11\xf8\x09\x94\xda\xce\xb9\xff\xa1\x6a\xc1\x00\x32\xbe\xf9\xf5\xb6\xbd\xb7\x0b\x8f\x1d\x42\x6d\x5e\x33\x0d\xcc\x16\xa0\x73\xe2\xe5\x9f\x24\xa5\x12\x8b\xbe\x63\x6c\x4e\x6e\xb7\xf8\x0e\x0c\x7f\x4f\x51\x6b\x0a\x5c\xb0\x9c\x68\xb8\x81\x1b\x3c\xef\x56\x5e\x90\x42\x90\x7c\xb1\xa9\xef\xc8\xe2\x92\x1e\x84\x77\x36\x9b\xb3\xad\xbc\x55\x01\x51\x71\xe2\xc1\xb0\x2b\x19\xb8\x00\xe2\x35\xc4\xb2\xb7\x5b\xee\x48\xde\xc0\xdc\x65\x72\xfd\x77\x41\x55\xe4\xda\x73\x8e\xdb\x26\x55\x49\x20\x85\x41\xc6\xc9\x84\xcd\x7e\x30\xf1\x9d\x5d\xe9\x64\x56\x2e\x60\xdb\x27\xd5\x84\x79\x14\x6a\x30\x8f\x6f\x07\x0c\xbf\x2a\xf5\x5b\xb8\x58\x63\x19\x31\x9d\xc4\xd6\x57\x39\x4a\x65\x63\xe2\xc4\xae\xd8\xea\xfd\x1b\xaf\x6d\x3f\xfb\xd3\xc4\x82\x1c\x4e\x71\xf7\xd7\xbf\x06\xb8\x25\xa0\x09\x53\xfc\xe4\xf8\x25\xe0\xb9\x20\x34\x83\xfa\xa2\x29\xed\xf8\x58\x5f\xb9\x54\xce\x29\x65\x4d\x2f\x56\x01\x28\x56\x35\x97\x2a\x33\xd5\x08\xa4\xe8\x0a\xc0\x86\x91\x98\x62\x1e\x27\xc0\x93\x53\xe0\xfc\x0f\xcc\x92\xd8\x1c\xd1\x89\x04\xe4\x33\xf8\xa2\x7e\x8f\xc5\x5b\x04\x2f\x38\xa6\xa4\x61\xb6\x1f\x0b\xa2\xa6\x73\x5d\x2a\x62\x2e\xf7\x4a\xba\x05\x76\x06\x9f\xea\x2e\xa3\xff\x07\xcc\xb8\x51\x07\x17\xcb\xeb\x13\x75\x59\x7f\xf1\x5a\x37\xc2\x24\xa5\x56\xa3\xcf\x94\x36\x9a\xd7\xe6\x3d\x7a\x0d\x9a\xde\xd5\x1f\x3a\x7d\xec', 2)

# cleanup
del pyarmor_runtime

